%define major     0
%define libname   %mklibname %{name} %{major}
%define devname   %mklibname %{name} -d

%global __provides_exclude_from %{python_sitearch}/osmosdr/.*\\.so$

Name:             gr-osmosdr
Summary:          Common software API for various radio hardware
Version:          0.2.4
Release:          %mkrel 7
License:          GPLv3+
Group:            Communications/Radio
URL:              https://github.com/osmocom/gr-osmosdr/releases

Source0:          https://github.com/osmocom/gr-osmosdr/archive/refs/tags/v%{version}/gr-osmosdr-%{version}.tar.gz
# https://osmocom.org/issues/5445
# https://osmocom.org/issues/5031
# Patch based on:
# https://github.com/dl1ksv/gr-osmosdr/commit/7d450ca7f20bcbf018a90662febcd9c5618372c2.patch
#Patch0:           gr-osmosdr-0.2.3-gr-funcube.patch
# https://osmocom.org/issues/5144
Patch1:           gr-osmosdr-0.2.3-airspy-multi-dev.patch

BuildRequires:    boost-devel
BuildRequires:    cmake
BuildRequires:    cmake(funcube)
BuildRequires:    doxygen
BuildRequires:    gcc-c++
BuildRequires:    gnuradio-utils
BuildRequires:    graphviz
BuildRequires:    mpir-devel
BuildRequires:    mpirxx-devel
BuildRequires:    pkgconfig(gmp)
BuildRequires:    pkgconfig(gmpxx)
BuildRequires:    pkgconfig(gnuradio-analog)
BuildRequires:    pkgconfig(gnuradio-digital)
BuildRequires:    pkgconfig(gnuradio-blocks)
BuildRequires:    pkgconfig(gnuradio-iqbalance)
BuildRequires:    pkgconfig(gnuradio-uhd)
BuildRequires:    pkgconfig(gnuradio-runtime)
BuildRequires:    pkgconfig(libairspy)
BuildRequires:    pkgconfig(libbladeRF)
BuildRequires:    pkgconfig(libhackrf)
BuildRequires:    pkgconfig(libmirisdr)
BuildRequires:    pkgconfig(python3)
BuildRequires:    pkgconfig(SoapySDR)
BuildRequires:    pkgconfig(uhd)
BuildRequires:    python-gnuradio-runtime
BuildRequires:    python3-numpy-devel
BuildRequires:    python3-mako
BuildRequires:    pybind11-devel
BuildRequires:    rtl-sdr-devel

%description
Primarily gr-osmosdr supports the OsmoSDR hardware, but it also
offers a wrapper functionality for FunCube Dongle,  Ettus UHD
and rtl-sdr devices. By using gr-osmosdr source you can take
advantage of a common software api in your application(s)
independent of the underlying radio hardware.

%package -n %{libname}
Summary:          Library files for gr-osmosdr
Group:            Communications/Radio
Requires:         %{name} = %{version}-%{release}

%description -n %{libname}
Library files for gr-osmosdr.

%package -n %{devname}
Summary:          Development files for gr-osmosdr
Group:            Communications/Radio
Requires:         %{libname} = %{version}-%{release}
Provides:         %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for gr-osmosdr.

%package doc
Summary:          Documentation files for gr-osmosdr
Group:            Communications/Radio
BuildArch:        noarch

%description doc
Documentation files for gr-osmosdr.

%prep
%autosetup -p1

%build
%cmake -DENABLE_DOXYGEN=on -DGR_PKG_DOC_DIR=%{_docdir}/%{name}
%cmake_build

%install
%cmake_install

cat > %{name}-doc.desktop << EOF
[Desktop Entry]
Version=1.0
Name=Gr-OsmoSDR Documentation
GenericName=Gr-OsmoSDR Documentation
Exec=xdg-open /usr/share/doc/%{name}/html/index.html
Icon=
Terminal=false
Type=Application
Categories=System;Documentation;X-Mageia-CrossDesktop;
EOF

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}-doc.desktop

# Create pkgconfig .pc file
mkdir -p %{buildroot}%{_libdir}/pkgconfig
cat <<EOF > %{buildroot}%{_libdir}/pkgconfig/gnuradio-osmosdr.pc
prefix=%{_usr}
exec_prefix=\${prefix}
libdir=\${exec_prefix}/%{_lib}
includedir=\${prefix}/include

Name: gnuradio-osmosdr
Description: GNU Radio block for various radio hardware
URL: https://sdr.osmocom.org/trac/wiki/GrOsmoSDR
Version: %{version}
Requires: gnuradio-runtime gnuradio-blocks
Requires.private:
Conflicts:
Cflags: -I\${includedir} -I/usr/include
Libs: -L\${libdir} -lgnuradio-osmosdr
Libs.private: -L\${libdir}
EOF

%files
%exclude %{_docdir}/%{name}/html
%exclude %{_docdir}/%{name}/xml
%doc AUTHORS COPYING
%{_bindir}/*

%{python_sitearch}/*
%{_datadir}/gnuradio/grc/blocks/*

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/osmosdr
%{_libdir}/*.so
%{_libdir}/cmake/osmosdr/*
%{_libdir}/pkgconfig/*.pc

%files doc
%doc %{_docdir}/%{name}/html
%doc %{_docdir}/%{name}/xml
%{_datadir}/applications/%{name}-doc.desktop


%changelog
* Tue May 14 2024 barjac <barjac> 0.2.4-7.mga10
+ Revision: 2064229
- rebuild for gnuradio-3.10.10.0

* Wed Apr 10 2024 barjac <barjac> 0.2.4-6.mga10
+ Revision: 2056348
- rebuild for gnuradio-3.10.9.2

* Fri Jan 12 2024 wally <wally> 0.2.4-5.mga10
+ Revision: 2030539
- rebuild for boost 1.84.0

* Fri Dec 29 2023 joequant <joequant> 0.2.4-4.mga10
+ Revision: 2023774
- update to py3.12

* Wed Sep 27 2023 wally <wally> 0.2.4-3.mga10
+ Revision: 1991445
- rebuild for boost 1.83.0

* Tue Jan 31 2023 barjac <barjac> 0.2.4-2.mga9
+ Revision: 1937163
- rebuild for uhd-4.4.0.0 gr etc

* Thu Jan 26 2023 barjac <barjac> 0.2.4-1.mga9
+ Revision: 1936240
- rebuild for gnuradio-3.10.5.1

* Sat Dec 24 2022 wally <wally> 0.2.3-0.20221118.de6de7bc.7.mga9
+ Revision: 1926477
- rebuild for boost 1.81.0
+ barjac <barjac>
- revert removal of mirisdr BR

* Sun Dec 04 2022 barjac <barjac> 0.2.3-0.20221118.de6de7bc.5.mga9
+ Revision: 1917902
- new snapshot
- drop mirisdr and osmo-sdr both dead upstream
- drop obsolete patches

* Sat Sep 17 2022 barjac <barjac> 0.2.3-0.20210217.a100eb02.4.mga9
+ Revision: 1889578
- rebuild for gnuradio-3.10.4.0

* Sat Aug 06 2022 barjac <barjac> 0.2.3-0.20210217.a100eb02.3.mga9
+ Revision: 1875562
- rebuild for gnuradio-3.10.3.0

* Sun Jul 03 2022 wally <wally> 0.2.3-0.20210217.a100eb02.2.mga9
+ Revision: 1867256
- rebuild for boost 1.79.0

* Mon Apr 25 2022 barjac <barjac> 0.2.3-0.20210217.a100eb02.1.mga9
+ Revision: 1853576
- new version 0.2.3
- patches synced from fc
- new BR cmake(funcube)

* Tue Apr 12 2022 barjac <barjac> 0.2.2.0-0.20210328.10.mga9
+ Revision: 1849092
- rebuild for gnuradio-3.10.2.0

* Tue Feb 22 2022 tv <tv> 0.2.2.0-0.20210328.9.mga9
+ Revision: 1782871
- Rebuild for python-3.10

* Fri Feb 04 2022 barjac <barjac> 0.2.2.0-0.20210328.8.mga9
+ Revision: 1771448
- rebuild for gr-3.10.1.1

* Sun Dec 19 2021 wally <wally> 0.2.2.0-0.20210328.7.mga9
+ Revision: 1762667
- rebuild for boost 1.78.0

* Sat Sep 25 2021 barjac <barjac> 0.2.2.0-0.20210328.6.mga9
+ Revision: 1746373
- Rebuild for gnuradio-3.9.3.0-rc1
- fix conditional
- add soapy-sdr support

* Thu Sep 09 2021 wally <wally> 0.2.2.0-0.20210328.5.mga9
+ Revision: 1744656
- rebuild for boost 1.77.0

* Sat Jun 19 2021 barjac <barjac> 0.2.2.0-0.20210328.4.mga9
+ Revision: 1731266
- rebuild for gnuradio-3.9.2

* Wed Jun 09 2021 barjac <barjac> 0.2.2.0-0.20210328.3.mga9
+ Revision: 1730253
- rebuild for volk-1.5.0

* Fri May 14 2021 wally <wally> 0.2.2.0-0.20210328.2.mga9
+ Revision: 1722967
- rebuild for boost 1.76.0

* Mon Mar 29 2021 barjac <barjac> 0.2.2.0-0.20210328.1.mga9
+ Revision: 1711593
- new snapshot gr_3.9 compatible
- swig replaced by pybind11-devel

* Thu Dec 31 2020 wally <wally> 0.2.2-6.mga8
+ Revision: 1666765
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 0.2.2-5.mga8
+ Revision: 1662007
- rebuild for boost 1.74.0

* Wed Nov 25 2020 barjac <barjac> 0.2.2-4.mga8
+ Revision: 1649217
- rebuild for volk-2.4

* Sat Oct 03 2020 tv <tv> 0.2.2-3.mga8
+ Revision: 1631919
- rebuild for new uhd

* Tue Sep 01 2020 barjac <barjac> 0.2.2-2.mga8
+ Revision: 1620685
- rebuild for gnuradio-3.8.2

* Tue Aug 11 2020 barjac <barjac> 0.2.2-1.mga8
+ Revision: 1613183
- new version 0.2.2
- remove obsolete patch

* Tue Jun 09 2020 barjac <barjac> 0.2.0-3.mga8
+ Revision: 1591092
- rebuild for volk-2.3.0

* Sun May 03 2020 wally <wally> 0.2.0-2.mga8
+ Revision: 1578446
- rebuild for boost 1.73.0

* Wed Mar 25 2020 barjac <barjac> 0.2.0-1.mga8
+ Revision: 1559582
- rebuild for volk

* Wed Feb 19 2020 barjac <barjac> 0.2.0-0.4.mga8
+ Revision: 1545017
- new version 0.2.0
- python3 enabled
- fcdproplus support dropped
- generate .pc in spec as dropped upstream
- add cmake files to -devel
- python sitelib not sitearch
- several new BRs mainly from gnuradio
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- rebuild for boost 1.72.0
- build with new cmake macros

* Sat Apr 20 2019 barjac <barjac> 0.1.4.127-3.mga7
+ Revision: 1394090
- rebuild for uhd-3.14.0.0

* Sat Jan 19 2019 barjac <barjac> 0.1.4.127-2.mga7
+ Revision: 1358132
- rebuild for gnuradio

* Thu Jan 10 2019 barjac <barjac> 0.1.4.127-1.mga7
+ Revision: 1354478
- new version 0.1.4.127

* Tue Oct 16 2018 wally <wally> 0.1.4.99-3.mga7
+ Revision: 1321043
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 0.1.4.99-2.mga7
+ Revision: 1298083
- Mageia 7 Mass Rebuild

* Mon Jul 09 2018 barjac <barjac> 0.1.4.99-1.mga7
+ Revision: 1242706
- new version 0.1.4.99
- fix mk-tar to properly exclude vcs and reduce tarball size

* Wed Jun 27 2018 barjac <barjac> 0.1.4.98-5.mga7
+ Revision: 1239948
- rebuild for gnuradio-3.7.13.3

* Tue Dec 26 2017 wally <wally> 0.1.4.98-4.mga7
+ Revision: 1185488
- update provides exclude format
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 0.1.4.98-2.mga7
+ Revision: 1178325
- rebuild for boost 1.65

* Thu Oct 26 2017 barjac <barjac> 0.1.4.98-1.mga7
+ Revision: 1173792
- new version 0.1.4.98
  > - use rtl-sdr-devel as current rtl-sdr has a pb with pkgconfig

* Thu Sep 08 2016 barjac <barjac> 0.1.4.72-6.mga6
+ Revision: 1050818
- rebuild for gnuradio-3.7.10.1

* Wed Jul 27 2016 barjac <barjac> 0.1.4.72-5.mga6
+ Revision: 1043772
- rebuild again for rebuilt gr-iqbal to fix arm build

* Wed Jul 27 2016 barjac <barjac> 0.1.4.72-4.mga6
+ Revision: 1043761
- Rebuild again for gr-fcdproplus built agianst new gnuradio

* Wed Jul 27 2016 tmb <tmb> 0.1.4.72-3.mga6
+ Revision: 1043736
- rebuild for new gnuradio

* Thu Apr 14 2016 barjac <barjac> 0.1.4.72-2.mga6
+ Revision: 1001550
- rebuild for gnuradio

* Tue Mar 22 2016 barjac <barjac> 0.1.4.72-1.mga6
+ Revision: 993856
- new version 0.1.4.72
- use pkgconfig style BRs where possible
- sort BRs

* Mon Feb 22 2016 barjac <barjac> 0.1.4.67-3.mga6
+ Revision: 976081
- rebuild for gnuradio

* Thu Feb 04 2016 barjac <barjac> 0.1.4.67-2.mga6
+ Revision: 935409
- build for arm

* Sat Jan 16 2016 barjac <barjac> 0.1.4.67-1.mga6
+ Revision: 924638
- new minor version 0.1.4.67

* Thu Dec 31 2015 barjac <barjac> 0.1.4.58-2.mga6
+ Revision: 917219
- rebuild for gnuradio-3.7.9

* Sun Dec 27 2015 barjac <barjac> 0.1.4.58-1.mga6
+ Revision: 915545
- rebuild for boost-1.60.0
- new snapshot
- use %%make_install macro

* Mon Dec 14 2015 barjac <barjac> 0.1.4.55-1.mga6
+ Revision: 910446
- new snapshot 0.1.4.55

* Sat Sep 26 2015 barjac <barjac> 0.1.4.48-4.mga6
+ Revision: 883948
- rebuild for boost-1.59

* Mon Sep 21 2015 barjac <barjac> 0.1.4.48-3.mga6
+ Revision: 882027
- new version 0.1.4.48

* Sun Jan 18 2015 barjac <barjac> 0.1.4.0-2.mga6
+ Revision: 811371
- Rebuild for updated gr-fcdproplus

* Sat Jan 17 2015 barjac <barjac> 0.1.4.0-1.mga5
+ Revision: 811202
- adapt for Mageia
- Import package from Fedora with thanks


* Tue Sep  2 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-16.20130729git9dfe3a63
- Rebuilt for new gnuradio

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.1-15.20130729git9dfe3a63
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jul 17 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-14.20130729git9dfe3a63
- Rebuilt for new gnuradio

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.1-13.20130729git9dfe3a63
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun May 25 2014 Petr Machata <pmachata@redhat.com> - 0.1.1-12.20130729git9dfe3a63
- Rebuild for boost 1.55.0

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 0.1.1-11.20130729git9dfe3a63
- rebuild for boost 1.55.0

* Mon May  5 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-10.20130729git9dfe3a63
- Enabled UHD support
  Resolves: rhbz#1093954

* Tue Mar 11 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-9.20130729git9dfe3a63
- Fixed pkgconfig version string

* Tue Mar 11 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-8.20130729git9dfe3a63
- Rebuilt for new gnuradio

* Mon Jan  6 2014 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-7.20130729git9dfe3a63
- Dummy release bump due to http://fedorahosted.org/rel-eng/ticket/5823

* Mon Dec  2 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-6.20130729git9dfe3a63
- Rebuilt for new gnuradio

* Mon Nov 18 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-5.20130729git9dfe3a63
- Rebuilt for new gnuradio

* Mon Sep  2 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-4.20130729git9dfe3a63
- Rebuilt for new gnuradio

* Tue Aug  6 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-3.20130729git9dfe3a63
- Used unversioned doc directory
  Resolves: rhbz#993807

* Mon Jul 29 2013 Petr Machata <pmachata@redhat.com> - 0.1.1-2.20130729git9dfe3a63
- Rebuild for boost 1.54.0

* Mon Jul 29 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.1.1-1.20130729git9dfe3a63
- New version
- Dropped doxygen-fix and docdir-override patches (upstreamed)

* Tue May 28 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.0.1-3.20130403gite85c68d9
- Rebuilt for new gnuradio

* Tue Apr  9 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.0.1-2.20130403gite85c68d9
- Packaged doxygen docs and examples
- Various improvements according to comments in the merge review

* Wed Apr  3 2013 Jaroslav Škarvada <jskarvad@redhat.com> - 0.0.1-1.20130403gite85c68d9
- Initial version
